@@ -6,10 +6,10 @@ Yet another Discord API wrapper for Python.
 :license: MIT
 """
 
-__version__ = "0.0.1"
+__version__ = "0.0.3"
 
 from .client import Client
 from .model.channel import *
 from .model.event import *
 from .model.gateway import Intents, Activity, ActivityTypes
-from .model.interactions.slashcommands import *
+from .model.interactions import *
