@@ -4,9 +4,9 @@ from .snowflake import Snowflake
 
 class Emoji:
     def __init__(self, client, resp):
-        self.id = Snowflake.optional(resp["id"])
+        self.id = Snowflake.optional(resp.get("id"))
         self.name = resp["name"]
-        self.roles = [client.get(x) for x in resp.get("roles", [])] if client.has_cache else None
+        self.roles = [client.get(x) for x in resp.get("roles", [])] if client.has_cache else [Snowflake.optional(x) for x in resp.get("roles", [])]
         self.__user = resp.get("user")
         self.user = User.create(client, self.__user) if self.__user else self.__user
         self.require_colons = resp.get("require_colons")
