@@ -1,5 +1,6 @@
 import typing
 from .slashcommands import ApplicationCommandInteractionData
+from .components import TemporaryComponentResponse, Component
 from ..channel import Embed, AllowedMentions
 from ..guild import Member
 from ..snowflake import Snowflake
@@ -13,7 +14,7 @@ class Interaction:
         self.id = Snowflake(resp["id"])
         self.application_id = Snowflake(resp["application_id"])
         self.type = InteractionType(resp["type"])
-        self.data = ApplicationCommandInteractionData(client, resp.get("data"))
+        self.data = ApplicationCommandInteractionData(client, resp.get("data")) if self.type.application_command else TemporaryComponentResponse(resp.get("data"))
         self.guild_id = Snowflake(resp.get("guild_id"))
         self.channel_id = Snowflake(resp.get("channel_id"))
         self.__member = resp.get("member")
@@ -62,12 +63,14 @@ class InteractionApplicationCommandCallbackData:
                  content: str = None,
                  embeds: typing.List[Embed] = None,
                  allowed_mentions: AllowedMentions = None,
-                 flags: int = None):
+                 flags: int = None,
+                 components: typing.List[typing.Union[dict, Component]] = None):
         self.tts = tts
         self.content = content
         self.embeds = embeds
         self.allowed_mentions = allowed_mentions
         self.flags = flags
+        self.components = components
 
     def to_dict(self):
         ret = {}
@@ -81,16 +84,18 @@ class InteractionApplicationCommandCallbackData:
             ret["allowed_mentions"] = self.allowed_mentions.to_dict()
         if self.flags is not None:
             ret["flags"] = int(self.flags)
+        if self.components is not None:
+            ret["components"] = [x if isinstance(x, dict) else x.to_dict() for x in self.components]
         return ret
 
 
 class InteractionResponse:
-    def __init__(self, callback_type: typing.Union[int, InteractionCallbackType], data: InteractionApplicationCommandCallbackData):
+    def __init__(self, callback_type: typing.Union[int, InteractionCallbackType], data: typing.Union[dict, InteractionApplicationCommandCallbackData]):
         self.type = callback_type
         self.data = data
 
     def to_dict(self):
-        return {"type": int(self.type), "data": self.data.to_dict()}
+        return {"type": int(self.type), "data": self.data if isinstance(self.data, dict) else self.data.to_dict()}
 
 
 class MessageInteraction:
